==> haskell-expiring-cache-map-0.0.6.1-417-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-expiring-cache-map.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 expiring-cache-map
version:              0.0.6.1
visibility:           public
id:                   expiring-cache-map-0.0.6.1-DWxPpfSvFyRJvBb8keL0WY
key:                  expiring-cache-map-0.0.6.1-DWxPpfSvFyRJvBb8keL0WY
license:              BSD-3-Clause
copyright:            (c) 2014 Edward L. Blake
maintainer:           edwardlblake@gmail.com
author:               Edward L. Blake
homepage:             https://github.com/elblake/expiring-cache-map
synopsis:             General purpose simple caching.
description:
    A simple general purpose shared state cache map with automatic expiration
    of values, for caching the results of accessing a resource such as reading
    a file. With variations for Ord and Hashable keys using "Data.Map.Strict"
    and "Data.HashMap.Strict", respectively.

category:             Caching
abi:                  d7ab325fa55c90cefd3f607c27c3cfe7
exposed:              True
exposed-modules:
    Caching.ExpiringCacheMap.HashECM
    Caching.ExpiringCacheMap.Internal.Internal
    Caching.ExpiringCacheMap.Internal.Types
    Caching.ExpiringCacheMap.OrdECM Caching.ExpiringCacheMap.Types
    Caching.ExpiringCacheMap.Utils.TestSequence
    Caching.ExpiringCacheMap.Utils.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/expiring-cache-map-0.0.6.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/expiring-cache-map-0.0.6.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/expiring-cache-map-0.0.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-expiring-cache-map
hs-libraries:         HSexpiring-cache-map-0.0.6.1-DWxPpfSvFyRJvBb8keL0WY
depends:
    base-4.17.2.1 containers-0.6.7
    hashable-1.4.6.0-8MG0S5dfyXU6lRGLMgbs1l
    unordered-containers-0.2.20-Iia3zhz8DVL3Efh3E6ja96

haddock-interfaces:
    /usr/share/doc/haskell-expiring-cache-map/html/expiring-cache-map.haddock

haddock-html:         /usr/share/doc/haskell-expiring-cache-map/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-expiring-cache-map-0.0.6.1-418-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-expiring-cache-map.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 expiring-cache-map
version:              0.0.6.1
visibility:           public
id:                   expiring-cache-map-0.0.6.1-A7iyjQsabGSJbWaSjx1agr
key:                  expiring-cache-map-0.0.6.1-A7iyjQsabGSJbWaSjx1agr
license:              BSD-3-Clause
copyright:            (c) 2014 Edward L. Blake
maintainer:           edwardlblake@gmail.com
author:               Edward L. Blake
homepage:             https://github.com/elblake/expiring-cache-map
synopsis:             General purpose simple caching.
description:
    A simple general purpose shared state cache map with automatic expiration
    of values, for caching the results of accessing a resource such as reading
    a file. With variations for Ord and Hashable keys using "Data.Map.Strict"
    and "Data.HashMap.Strict", respectively.

category:             Caching
abi:                  debf4389cc9e59834bb3b7d3760ba3c4
exposed:              True
exposed-modules:
    Caching.ExpiringCacheMap.HashECM
    Caching.ExpiringCacheMap.Internal.Internal
    Caching.ExpiringCacheMap.Internal.Types
    Caching.ExpiringCacheMap.OrdECM Caching.ExpiringCacheMap.Types
    Caching.ExpiringCacheMap.Utils.TestSequence
    Caching.ExpiringCacheMap.Utils.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/expiring-cache-map-0.0.6.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/expiring-cache-map-0.0.6.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/expiring-cache-map-0.0.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-expiring-cache-map
hs-libraries:         HSexpiring-cache-map-0.0.6.1-A7iyjQsabGSJbWaSjx1agr
depends:
    base-4.17.2.1 containers-0.6.7
    hashable-1.4.6.0-AnOmtRToJbI9DS9f6Gdy0i
    unordered-containers-0.2.20-KDi8IgRcOV5HCm7hBAqDWV

haddock-interfaces:
    /usr/share/doc/haskell-expiring-cache-map/html/expiring-cache-map.haddock

haddock-html:         /usr/share/doc/haskell-expiring-cache-map/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
